/*
 * QUOTA    An implementation of the diskquota system for the LINUX operating
 *          system. QUOTA is implemented using the BSD systemcall interface
 *          as the means of communication with the user level. Should work for
 *          all filesystems because of integration into the VFS layer of the
 *          operating system. This is based on the Melbourne quota system wich
 *          uses both user and group quota files.
 * 
 *          Program to query for the internal statistics.
 * 
 * Author:  Marco van Wieringen <mvw@planets.elm.net>
 *          Few updates by Jan Kara <jack@atrey.karlin.mff.cuni.cz>
 *
 *          This program is free software; you can redistribute it and/or
 *          modify it under the terms of the GNU General Public License as
 *          published by the Free Software Foundation; either version 2 of
 *          the License, or (at your option) any later version.
 */

#include <stdio.h>
#include <sys/types.h>
#include <asm/types.h>
#include <linux/quota.h>

static inline int get_stats(struct dqstats *dqstats)
{
   return quotactl(QCMD(Q_GETSTATS, 0), (char *)NULL, 0, (caddr_t)dqstats);
}

static inline int print_stats(struct dqstats *dqstats)
{
   printf("Number of dquot lookups: %ld\n", (long)dqstats->lookups);
   printf("Number of dquot drops: %ld\n", (long)dqstats->drops);
   printf("Number of dquot reads: %ld\n", (long)dqstats->reads);
   printf("Number of dquot writes: %ld\n", (long)dqstats->writes);
   printf("Number of quotafile syncs: %ld\n", (long)dqstats->syncs);
   printf("Number of dquot cache hits: %ld\n", (long)dqstats->cache_hits);
   printf("Number of allocated dquots: %ld\n", (long)dqstats->allocated_dquots);
   printf("Number of free dquots: %ld\n", (long)dqstats->free_dquots);
   printf("Number of in use dquot entries (user/group): %ld\n",
           (long)(dqstats->allocated_dquots - dqstats->free_dquots));
   return 0; 
}

int main(void)
{
   struct dqstats dqstats;

   if (!get_stats(&dqstats))
      print_stats(&dqstats);
   return 0;
}
